pub enum Call<T: Config> {
fractionalize {
nft_collection_id: T::NftCollectionId,
nft_id: T::NftId,
asset_id: AssetIdOf<T>,
beneficiary: AccountIdLookupOf<T>,
fractions: AssetBalanceOf<T>,
},
unify {
nft_collection_id: T::NftCollectionId,
nft_id: T::NftId,
asset_id: AssetIdOf<T>,
beneficiary: AccountIdLookupOf<T>,
},
// some variants omitted
}Expand description
Contains a variant per dispatchable extrinsic that this pallet has.
Variants
fractionalize
Lock the NFT and mint a new fungible asset.
The dispatch origin for this call must be Signed. The origin must be the owner of the NFT they are trying to lock.
Deposit funds of sender are reserved.
nft_collection_id: The ID used to identify the collection of the NFT. Is used within the context ofpallet_nfts.nft_id: The ID used to identify the NFT within the given collection. Is used within the context ofpallet_nfts.asset_id: The ID of the new asset. It must not exist. Is used within the context ofpallet_assets.beneficiary: The account that will receive the newly created asset.fractions: The total issuance of the newly created asset class.
Emits NftFractionalized event when successful.
Fields
nft_collection_id: T::NftCollectionIdbeneficiary: AccountIdLookupOf<T>fractions: AssetBalanceOf<T>unify
Burn the total issuance of the fungible asset and return (unlock) the locked NFT.
The asset is destroyed as well, unless it still has asset accounts – from touch –
or approvals, or the asset registry refuses, in which case anyone can finish the
destruction later.
The dispatch origin for this call must be Signed.
Deposit funds will be returned to asset_creator.
nft_collection_id: The ID used to identify the collection of the NFT. Is used within the context ofpallet_nfts.nft_id: The ID used to identify the NFT within the given collection. Is used within the context ofpallet_nfts.asset_id: The ID of the asset being returned and destroyed. Must match the original ID of the created asset, corresponding to the NFT. Is used within the context ofpallet_assets.beneficiary: The account that will receive the unified NFT.
Emits NftUnified event when successful.
Implementations
Sourceimpl<T: Config> Call<T>
impl<T: Config> Call<T>
Sourcepub fn new_call_variant_fractionalize(
nft_collection_id: T::NftCollectionId,
nft_id: T::NftId,
asset_id: AssetIdOf<T>,
beneficiary: AccountIdLookupOf<T>,
fractions: AssetBalanceOf<T>,
) -> Self
pub fn new_call_variant_fractionalize( nft_collection_id: T::NftCollectionId, nft_id: T::NftId, asset_id: AssetIdOf<T>, beneficiary: AccountIdLookupOf<T>, fractions: AssetBalanceOf<T>, ) -> Self
Create a call with the variant fractionalize.
Sourcepub fn new_call_variant_unify(
nft_collection_id: T::NftCollectionId,
nft_id: T::NftId,
asset_id: AssetIdOf<T>,
beneficiary: AccountIdLookupOf<T>,
) -> Self
pub fn new_call_variant_unify( nft_collection_id: T::NftCollectionId, nft_id: T::NftId, asset_id: AssetIdOf<T>, beneficiary: AccountIdLookupOf<T>, ) -> Self
Create a call with the variant unify.